@@ -179,14 +179,12 @@ data Config =
 
 instance ToJSON Config where
   toJSON Config{..} =
-      object [ "haskell" .= r ]
-    where
-      r = object [ "checkParents"                .= checkParents
-                 , "checkProject"                .= checkProject
-                 , "formattingProvider"          .= formattingProvider
-                 , "maxCompletions"              .= maxCompletions
-                 , "plugin"                      .= Map.mapKeysMonotonic (\(PluginId p) -> p) plugins
-                 ]
+    object [ "checkParents"                .= checkParents
+           , "checkProject"                .= checkProject
+           , "formattingProvider"          .= formattingProvider
+           , "maxCompletions"              .= maxCompletions
+           , "plugin"                      .= Map.mapKeysMonotonic (\(PluginId p) -> p) plugins
+           ]
 
 instance Default Config where
   def = Config
@@ -531,6 +529,9 @@ instance PluginMethod Request Method_CallHierarchyOutgoingCalls where
   -- This method has no URI parameter, thus no call to 'pluginResponsible'
   pluginEnabled _ _ pluginDesc conf = pluginEnabledConfig plcCallHierarchyOn (configForPlugin conf pluginDesc)
 
+instance PluginMethod Request Method_WorkspaceExecuteCommand where
+  pluginEnabled _ _ _ _= True
+
 instance PluginMethod Request (Method_CustomMethod m) where
   pluginEnabled _ _ _ _ = True
 
